---
title: "Aristotle 101: the Aporia of Future Contingency"
date: 2020-05-15T11:15:48Z
tags: ["free will","determinism","time","change"]
topics: ["philosophy"]
image: img/aristotle-and-salamis.jpg
draft: false
---

In On Interpretation, Aristotle presents the thought experiment of the sea battle in order to grapple with a logical paradox stemming from his commitment to correspondence in truth and the Law of Excluded Middle on the one hand, and his commitment to potentiality in the future, on the other. Given these commitments, if we are to say that there will be a sea battle tomorrow, then two questions (at least) need to be considered. First, is it *already* true that there will be one? Second, is its occurrence *already* determined by that? The term “already” is an important key to understanding these questions. It suggests a role for necessity in answering this problem. This essay will briefly summarize the logical problem, outline some possible solutions to the problem, and conclude with shrugging resignation at the fact that there isn’t more extant writing from Aristotle on the question.

Aristotle commits himself implicitly in a number of places, to a very crude correspondence theory of truth. Which is to say, that the valence of any statement is determined by our observational experience of things in the world, as they relate to that statement. For example, “the sky is blue” is either true or false, relative to the color of the sky. Implied by what I just stated, Aristotle is also committed to the Law of Excluded Middle (hereafter, “LeM”). In brief, this just means that the statement “the sky is blue” *must be* either true or false. This is because the observational experience of the sky can only either correspond to the affirmation, or not correspond. For objects in the present, the consequence of these commitments is straightforward: “Socrates is not Aristotle” is *necessarily true* (because it logically must be the case, from the Law of Identity); necessarily, “the sky is blue” (because of the nature of gaseous mixtures and the properties of light causally determine our experience of it).

However, these commitments cause interesting things to happen when we start making statements about *activities* (like sea battles), particularly when they have yet to take place. What are we referencing, when we say, “a sea battle will take place tomorrow”? There is no observational experience to point to, as yet. So, what truth value could we hope to place on this statement, and how would we assign it? What’s worse, If we maintain our commitment to correspondence and LeM, then we’ll have to deny both deliberative choice and chance, in favor of some form of fatalism or determinism — something that would require Aristotle, at a minimum, to abandon his Ethics. However, if we maintain our commitment to deliberative choice and chance, then we’ll have to either abandon correspondence as a basis for truth, or LeM as a rule for assigning truth values. Neither of which Aristotle is willing to surrender.

Aristotle’s solution to this problem seems to be to apply a concept of conditional necessity on truth, in order to preserve potentiality in the future. After stating the problem himself, he states, “whatever is, necessarily is, *when it is*; and what is not, necessarily is not, *when it is not*…” and he goes on to argue, “to say that everything that is, is of necessity, when it is, is not the same as saying *unconditionally* that it is of necessity…”. So, the distinction he is drawing is between conditional and unconditional necessity. He says some things are necessarily so all the time, but some things are only necessarily so, at the point in time when they are. If we apply LeM to this, then we arrive at a situation in which all statements are either true or false as an unconditional necessity, but only conditionally necessary, when the condition of their occurrence has been met. Thus, for any statement about a future activity, such as, “there will be a sea battle tomorrow”, two states of affairs hold:

1. It is necessary that the statement is either true or false, because these are the only values the statement could have, but potentiality requires that two values remain possible; and,
2. the statement is necessarily true, when it is true, and necessarily false, when it is false, because the point in time when the state of affairs arises will necessitate one value be assigned to the statement.

One way to interpret this, in answer to our original question, is to see Aristotle’s argument at the end of chapter 9 as saying that it is not necessary (i.e. determined) that the sea battle should happen, on account of our assertion, but it is necessary that the sea battle is *possible* on account of our assertion, and that our assertion will be true, when the sea battle takes place; false, when the sea battle does not take place.

While this solution may not entail three-valued logic, it certainly heavily implies a sort of purgatorial limbo for our statement: *undefined*. Which is to say, that there may be a missing piece to our understanding of Aristotle’s correspondence theory. Aristotle says that a statement must be “either true or false”, in the sense that it cannot be “somewhat true”, or even “possibly false”, in the “middle value” sense. But, that a statement may be “either true or false” is itself a kind of middle value. The true-or-false setting. So, he must be positing statements that have not yet had their values actualized, at all. Perhaps their truth values exist as “true-or-false” when in a state of potentiality rather than actuality? This would be consistent with his statements about the sea battle itself (that it neither necessarily must happen, nor that it necessarily must not happen). But an evaluation of this will have to wait for another time.

```[Imported from exitingthecave.com on 29 November 2021]```

