---
title: "Doubt and Descartes Existence"
date: 2016-10-01T18:08:30Z
tags: ["skepticism","rationalism","cartesian dualism","desartes"]
topics: ["philosophy"]
image: img/the_matrix.jpg
draft: false
---

The proposition ‘*I am, I exist*’ (*ego sum, ego existo* – hereafter, referred to as the ’*ego*’), is of special importance in the argument of Descartes’ Second Meditation for many reasons. More generally, it is important because of the implications it has for Descartes’ overall philosophical project. For example, it implicitly rejects religious authority in favor of a personal standard of knowledge in an era in which Galileo faced aggressive persecution; it also forms the nascent beginning of the still ongoing nature-nurture debate, and it ultimately makes Descartes something of an Augustinian. But these topics are far too broad to cover adequately in a brief essay. Since the language of the question at hand focuses exclusively on the the Second Meditation and specifically the argument within it, a much narrower interpretation seems more appropriate. Namely, why is the ‘*ego*’ necessary for Descartes to achieve his goal in the Second Meditation, and how does it facilitate that goal? On this point, I will argue that there is one fundamental reason. Namely, without the *ego*, Descartes has no means by which to recover from the corrosive power of his own method of doubt. I will outline and analyze this reason, focusing on whether the ‘*ego*’ satisfies the logical and epistemic demands put upon it by the method. Finally, I will argue that because Descartes is unclear in his justification for the *ego*, it remains unconvincing as a basis for epistemic certainty.

#### Doubt, Absolute Certainty, And The Whirlpool

A central feature of Descartes’ Method of Doubt is an absolute standard for what he will allow himself to identify as knowledge. He states in Meditation One: “*…we should withhold assent just as carefully from whatever is not completely certain and indubitable as from what is clearly false…*”. In other words, for the purposes of his method, he makes no distinction, nor accommodates any gradation, between the weakest of doubts and the worst of errors. All of these shades of gray are to be judged identically false. As a consequence, he admits he is, “…*forced to concede eventually that there is nothing… that cannot be doubted…*”, and by the beginning of Second Meditation, he recognizes the extreme position this puts him in, vowing to find a way to extricate himself:

> “*…I am so tossed about, as if I had fallen suddenly into a deep whirlpool, that I can neither put my foot on the bottom nor swim to the surface. However… I will follow [the method of doubt] until I discover something that is certain or, at least, until I discover that it is certain only that nothing is certain. Archimedes looked for only one firm and immovable point in order to move the whole earth; likewise, I could hope for great things if I found even the smallest thing that is certain and unmoved…*”

Finding this Archimedean point, then, is the challenge he faces in the Second Meditation. But what does this entail, exactly? To begin, we need to understand the standard of knowledge that has driven him to this point. In other words, what does Descartes mean by certainty? He defines it in The Meditations thus far only in silhouette, as a belief held “without doubt”. But to clearly understand his predicament it would help to understand what, for Descartes, constituted epistemic certainty. On this question, Descartes offers very little in the Meditations in the way of a complete explanation. However, he does provide some helpful details in an earlier work entitled, “*Rules For the Direction of The Mind*”. Rule three provides a direct and concise answer, in fact:

> “*…let us here enumerate all the acts of our intellect through which we can arrive at knowledge of things without any fear of error. We admit only two: **namely, intuition and deduction**.*”

#### The Acts Of The Intellect

Unfortunately, Descartes does not explain why these two particular acts of the intellect are the only two options. However, he does a fair amount of work to describe how they function separately as paths to knowledge. First, on intuition, he explains that it something quite different from the common-sense conception:

> “*…By intuition I understand neither the fleeting testimony of the senses nor the deceptive judgment of the imagination with its false constructions, but a conception of a pure and attentive mind, so easy and so distinct, that no doubt at all remains about what we understand. Or, what comes to the same thing, intuition is the indubitable conception of a pure and attentive mind arising from **the light of reason alone**; it is more certain even than deduction, because it is simpler, even though, as we noted above, people cannot err in deduction either. **Thus everyone can intuit with his mind that he exists, that he is thinking**, that a triangle is bounded by only three lines, a sphere by a single surface, and the like…*”

Descartes actually restates the “light of reason” notion in Meditation Three. So, we can be reasonably sure that the concept remained roughly the same for him in the gap between the writing of *Rules* and *Meditations*. He does not explain in the *Rules* how that “indubitable conception” is arrived at, except to assert that it arises from that “light of reason”. In The Meditations, he also adds that intuition is necessarily trustworthy, because none of the other “faculties” share the indubitable character of the faculty from which this notion arises.

> “…*whatever is shown to me by **the natural light of reason** – for example, that from the fact that I doubt it follows that I exist, and similar things – cannot in any way be doubtful, because there cannot be another faculty which I trust as much as that light and which could teach me that the conclusion is not true*…”

He gives us an argument in the third Meditation for how intuition achieves this absolute undoubtable character, by way of a fairly lengthy chain of reasoning meant also to provide his first proof of the existence of God. An analysis of that argument (and the so-called ‘Cartesian Circle’ created by it) is beyond the scope of this essay. So, I will only roughly summarize Descartes’ justification, here: The ideas in my mind are something that require a cause which, at least in some cases, cannot be myself. That cause is necessarily God, because the regress must end somewhere, and that end must be the necessary source, and the most perfect of ideas. Namely, God.

Moving on to the intellectual act of deduction, he argues first in rule two of *Rules*, that deduction is like mathematics and geometry because it’s objects are “pure and simple”, and this makes intelligible knowledge superior to sensible knowledge:

> “…*we must observe that we can arrive at knowledge of things by two paths, namely by experience or by deduction. We must observe, further, that while experiences of things are often deceptive, deduction or a pure inference of one thing from another, though it may be passed over if it is not noticed, can never be erroneously executed by an intellect even minimally rational…*”

And further, he assigns the same certainty to this sort of reasoning, as he does to his intuition, precisely because of it’s independence from the senses:

> “…*mathematics and geometry… alone are concerned with an object so pure and simple that they suppose absolutely nothing which experience has rendered uncertain, but they consist entirely in consequences rationally deduced… [Thus], one must conclude… that those who seek the right road of truth should not occupy themselves with any object concerning which they cannot possess a certainty equal to that of the demonstrations of arithmetic and geometry…*”

In the Meditations, again, he repeats this conception of (and commitment to) mathematical thought as a form of certainty, both in his opening letter to the Sorbonne, and in the First Meditation. The end result is that, for Descartes, nothing is worthy of the label “knowledge” or “certainty”, unless he can intuit it from the “*light of pure reason*” in a single spontaneous instant, or infer it directly in a single step from such an intuition. As he puts it in The Rules:

> “…*From all this we may conclude that those propositions which follow immediately from first principles are known according to the way we look at it, now by intuition, now by deduction, but that the first principles themselves are known only by intuition, and the remote conclusions, in contrast, only by deduction…*”

From the outset of his project, then, we can see that Descartes is anxious to find some kind of unassailable object of the mind that is beyond the reach of empirical rejection or denial by reasoned argument, upon which he can construct an epistemological edifice that will function as the basis for his science. But from what “first principle” can he begin this chain of very small, singular, and “certain” logical inferences? Well, to reiterate what he says in the *Rules*, “*everyone can intuit with his mind that he exists, that he is thinking*” In other words, *Cogito, Ergo Sum*. Or, even more simply as the necessary conclusion stated in Meditation Two.

#### Argument or Intuition?

Does the ‘*ego*’ succeed as this singular, certain, self-evident intuition? To begin with, it isn’t clear in the Second Meditation that Descartes has in fact established the proposition *as an intuition* by his own standard. For example, there are three obvious arguments presented near the start of the essay:

#### Argument 1:

1. If I am having thoughts, then I am something.
2. I am having thoughts
3. C1: I am something

#### Argument 2:

1. If I convinced myself of something, then I exist
2. I convinced myself that there is no material world (From Meditation 1)
3. C2: I exist

#### Argument 3:

1. If it is possible that a powerful demon is deceiving me, then I exist
2. It is possible that a powerful demon is deceiving me (from Meditation 1)
3. C3: I exist

All of these are stated in quick succession immediately prior the conclusion, “…*this proposition ‘I am, I exist’ is necessarily true whenever it is stated by me or conceived in my mind*…” If Descartes had not intended to express his existence as a conclusion following necessarily from premises (i.e., as an argument), or as a result of a series of arguments, then why even include these? If the intent was to demonstrate the “*clear and distinct*” idea of his own existence, wouldn’t it have been wiser to point out the absurdity in the inverse assertion (“*I am not, I do not exist*”)? Descartes actually hints at this in his explication of intuition in the *Rules*, even going so far as to assert the intuitive obviousness of our own self-existence. And, in response to Mersenne and Gassendi, in the *Objections And Replies*, Descartes explicitly denies that he is making an argument. He rejects their particular attempt to state the *cogito* in the traditional formulation of a strict syllogism, which contains a major general premise (in this case suppressed) and a minor particular premise:

1. SP: Whatever is thinking must exist
2. I am a thinking
3. C1: I exist

By my reading, this is close, but not quite what Descartes is doing in the Second Meditation. Yet also by my reading, it still seems clear that he is indeed making an argument (three of them, in fact, as I have demonstrated above). But so what? Let’s grant momentarily that this criticism is sufficient to render both the *ego* and the *cogito* either as arguments, or the conclusions to arguments. Still, Descartes’ own standard of knowledge included both intuition, *and* deduction. Do the Modus Ponens interpretations above conform to Descartes’ understanding of the kind of deduction that constituted epistemic certainty? And, if they don’t, where does this leave the *ego*?

Judging by his statements about deduction in the *Rules*, it’s not so clear. On the one hand, he suggests a sort of apparent obviousness that requires no formal reasoning at all, such as the contemplation of geometric shapes. On the other, he describes a process by which we are moving from an axiom to an inference based on the axiom. There doesn’t seem to be any clear guidance on which of the two conceptions is preferable. In fact, Descartes himself seemed to recognize this muddled distinction, and tried to clarify it in the *Rules*:

> “*there may now be some doubt as to why we should have added here another mode of knowledge besides intuition, that is, one proceeding by deduction, by which we understand all that is necessarily inferred from other things that are certainly known. But this procedure was necessary, since many things are known with certainty which nevertheless are not themselves evident, simply because they are deduced from true and known principles by the continuous and uninterrupted movement of a mind which clearly intuits each step… Therefore we distinguish here intuition from certain deduction by the fact that some movement or succession is conceived in the latter but not in the former…*”

In this context, it seems to me the Modus Ponens interpretations may be a more charitable understanding of Descartes than the form prescribed by Mersenne or Gassendi, since you could read the first two premises as a sort of simultaneous set of propositions, phrased for example, like: “*the ‘I’ exists, **and** is convinced*”. Yet, it seems to me that all that this really amounts to, is an attempt to make the argument *look like* an intuition — the only thing, really, that Descartes is willing to countenance as a “first principle” in his epistemology. Which puts us right back where we started: at a loss to discover “*one firm and immovable point*”, from which to lever the rest of our thinking.

#### Conclusion

The standard of knowledge that Descartes defines for himself in the beginning of *Meditations* is absolute certainty. He insists that only those things that we can assert with unflinching conviction should be granted the status of truth or knowledge. He tells us that this sort of “clear and distinct” certainty is only possible in the “light of reason”. While Descartes may assert, “*…as a general rule… everything that I perceive very clearly and distinctly is true.*”, I find I have to agree with another author, that “*The notion of a clear and distinct idea is, unfortunately, one of Descartes’ least clear and distinct notions.*” And, as I have shown, there is even less ground for confidence in his idea as a deduction, since even Descartes himself insists that it is not, and the more charitable forms are simply begging the intuition. Applying Descartes’ own standard, then, there is no good reason to believe he exists, and I think Descartes would agree:

> “*…we should be warned never at any time to admit any conjectures what- soever as an admixture to our judgments on the truth of things. This counsel is of no small importance. For the chief reason why nothing is found in the vulgar philosophy so evident and certain as to be incapable of controversial treatment is this: scholars, not content with knowing what is clear and certain, first hazarded further affirmations about obscure and unknown matters which they arrived at only by probable conjectures;…*”

While it’s true that Descartes’ method of doubt is useful occasionally, as a tool for highlighting hidden assumptions and implicit errors in thinking, Descartes’ use of it in the *Meditations* has a very different purpose. He says in passing, in the First Meditation, that he wants to make an advancement to “the sciences”. But that term had a very different meaning for him, than it does for us some 400 years later. Many writers and commentators excuse Descartes’ religiosity in his writings as a necessary self-defense in an era in which Galileo faced extreme danger for his confrontations with the church. But this does not correspond with the biography of Descartes the man, as I understand him. For all his skepticism, Descartes was fundamentally committed to his belief in God. And this was an explicit goal of the Meditations: “*God’s existence and the distinction between the human soul and the body are demonstrated*”. Nothing I’ve read so far, gives me any cause to believe this goal was disingenuously bolted on to the work, to appease ecclesiastical tyrants.

The *Meditations* is replete with black-and-white dichotomies, and impossible situations. The insistence on absolute certainty itself is a perfect example of that. This sort of thinking raises my own skeptical alarm bells. It typically arises out of two situations: (1) there is a problem with the language used in the argument, or some terms are not well understood, or (2) the author is determined to arrive at a preconceived conclusion, at all costs. As I have shown, Descartes clearly suffers from both Maladies. He needs knowledge to begin with something fundamentally separate from common experience, and yet fundamentally personal, in order to get to his God. To do this, he needs a standard of knowledge that divorces him from reality, and from authority. This is what motivated Descartes to put the *ego* (and the *cogito*) at center stage. Because without it, his argument is empty, and — at least for him — there is no reality.

```[Imported from exitingthecave.com on 1 December 2021]```

