---
title: "Two Custodians: On the Purpose of the State"
date: 2020-06-13T21:42:11Z
tags: ["authority","conservatism","enlightenment","legitimacy","liberalism","tolerance"]
topics: ["philosophy","politics","history"]
image: img/voltaire-reading.jpg
draft: false
---

Traditionally, there are two great debates at the core of political philosophy. The first is what justifies political authority, and the second is what should be the form of the institution that assumes that authority. The first debate includes questions of fundamental justice. Issues like what the state owes to its subjects, and what the subjects owe to each other, are central to the debate. The second debate depends somewhat on the answer to the first, in that it seeks to answer how the duties, obligations, rights, and responsibilities of the first debate are to be enacted and enforced. Should offices be permanent or temporary? Should powers be segregated? Should it include democratic mechanisms? Who should be enfranchised? Should it be federated or centralized? Should it monopolize certain goods? And so forth.

But, there is a further even higher level debate that has arisen as a consequence of the political transformation of the west over the last three hundred odd years. It is a debate that seems to be taking place largely unconsciously, near as I can tell, and expressing itself in secondary disputes around things like “tolerance” and “inclusion”. To understand this debate, I need to back up a bit to cover a few points from that three hundred years of history.

Coming out of the Thirty Years war in Europe, most states in the west were fairly well established monarchies governing regional or ethnic constituencies of limited geographical scope. The Holy Roman Empire had more or less disintegrated into dozens of culturally self-identified principalities; the Swiss confederacy, the Habsburg monarchy, the Brandenburg-Prussia monarchy, the Hanoverian kingdom, and of course, the French, Dutch, English, and Spanish crowns. These kingdoms, to some extent, were literally extended families. The royals were all inter-marrying (in order mostly to avoid having to marry the peasantry), and the peasantry identified itself with it’s royal family. This self-identification is actually still present vestigially in England. The English crown provides a kind of vague archetypal template for what an English family should think of itself (in addition to establishing class definitions).

During the height of the Enlightenment, immediately following the Thirty Years war, much of the thinking about the nature of crowns and sovereigns changed radically (though, not quite as radically as might be thought – but more on that later). Thinkers like Hobbes, Locke, Rousseau, and Montesquieu, began to consciously systematize European politics through the lens of their naturalistic, rational philosophical outlook. These thinkers were some of the first since late antiquity to ask fundamental questions about the legitimacy, form, and purpose of the state. The rationalism they took from the Greeks, drove them to seek in quasi-scientific fashion, unifying answers to these questions. Answers that would explain in reductive absolute terms, what the sovereign was for, what duties he must execute, what his subjects owed to him, and how the relationship was to be carried out in practice. Following the lead of Bacon and Newton, they tried to look at the world to discern its order by observation. Only, for them, it was the order inherent in man’s relations that they sought, rather than the relations of inanimate objects in nature.

But we should be clear about what was really going on, here. This was not a disinterested, agnostic, secular examination of political economy. This was work that was informed by training in classical philosophy, and heavily influenced by Anglo-Catholic assumptions about the meaning and purpose of life, and the fundamental value of mankind as a creature touched by the divine. Some will dispute this characterization, pointing to Voltaire, Rousseau, Hobbes, or Hume, and all the rumors of atheism swirling around them. I don’t want to debate that here. What I think we can agree on, was that despite their conscious declarations for or against religion, it is clear from their work, that it was heavily characterized by both the totalizing impulses of Greek rationalism, and the universalizing impulses of Anglo-Catholic religiosity. And this is especially important. Because it points to the new debate I see raging now (albeit a subconscious one). A debate that has very likely been going on in the arena of active politics, since the early 19th century.

Fundamentally, the debate comes down to this: what *philosophical purpose* does the state serve?

The pre-Enlightenment state clearly served as a kind of extension of the family as an organizing principle, and functioned as the standard bearer for a set of moral and political values through which the subjects obtained their own purpose, and organized their lives. In short, the state was a *custodian* of a regional or ethnic tradition, and it’s sovereign was the conservator of that custodial authority. This is why lines of succession are so important, and why identification with the sovereign was essential. If the people did not trust the sovereign to properly conserve the political tradition, he was on very shaky ground. Just ask George I of England, if you need to see this in action.

But the post-Enlightenment state was a different animal altogether, at first at leat, on paper. The Enlightenment state was no longer a custodian of a parochial tradition, but it remained a custodian. Only, this time, it was to serve as the custodian of the universal law of justice, as discovered by the political naturalist, and as expressed in political doctrines. This universal law was to have as its pillars several absolute principles, like the principles of physics that came from Newton or the principles of biology that came from Mendel and Lewenhoek; the primary principles they discovered were, Liberty and Equality. This was the first step toward the modern liberal democracy, which arguably saw its full realization in the federal republic instituted by the intellectual offspring of Locke and Rousseau, in America (but mainly, Locke).

Over the past two hundred plus years, the debate has evolved. The conception of the state as custodian of a parochial tradition, was mutated into the identitarian nationalism of the Nazis, by way of German philosophy (which is too complex to get into here). The conception of the state as custodian of a universal law of justice for all mankind, has been transformed by scientistic approaches to human social-psychology, and post-modern critiques of Enlightenment rationalism, into a sort of value-neutral dispute resolution platform, refereeing between participants in a socio-political football match. It is this conception of the state that I want to pick apart.

The post-modern critiques have some basis to them, which is why they’ve never really gone away. But the consequence has been to drive commitments to principled universalism into remission, mainly because traditional lines of defense for its principles have been rendered mute by the abandonment of a commitment to truth itself. What we are left with is essentially, a political scaffolding that hangs on to nothing but a globally totalized order for order’s sake, as its fundamental value. The purpose of one-world government is, well, just to get to one. Because one is better than many. And, oddly, we’re back to Parmenides yet again.

But there is a problem with this analysis. The impartial broker can only broker justice, if it knows what justice is, and it can only know what justice is, if it is commited to a set of values that express justice. In other words, there can be no such thing as an value-neutral custodian of a universal law of justice, because to be such a custodian requires commiting to certain values from which justice is constituted. Namely, a justifiable arrangement of Liberty and Equality.

This is why the modern liberal democratic state seems to be so obsessed with questions of “tolerance” especially. Tolerance is a proxy debate. What is it that the liberal state is being asked to tolerate, primarily? Generally, what it regards as “intolerance”. What is that “intolerance”, when you look at it closely? Typically, a minority community that acts as a self-subsistent custodian for its own peculiar set of values and traditions, that if the modern liberal state were genuinely value-neutral, wouldn’t concern it at all. But it is very concerned. Often to the point of neurosis. Why?

Because the value-neutral custodian of universal justice isn’t value-neutral at all, but cannot name its values anymore – either because it has forgotten them, or because it has become frightened by its own origin. Or maybe both. Modern liberal democracy yearns for globalization schemes internationally, and “inclusion” schemes domestically, because it still yearns for the universal justice that it was originally tasked with conserving, but now, can no longer identify. So, it scrabbles in the dark for substitutes. And in the process, it will give birth to abominable injustices every bit as horrifying as anything the Nazis ever aspired to.

```[Imported from exitingthecave.com on 28 November 2021]```

