---
title: "The Struggle Between Public and Private"
date: 2019-06-09T12:49:57Z
tags: ["ethics","politics","sociology","feminism","orwell","social media","technocracy"]
topics: ["philosophy","culture"]
image: img/private-man.jpg
draft: false
---

The world around me is getting ever more crazy, with each passing day. Politics is rapidly consuming all aspects of life within itself. We’ve reached a point in some areas of society where nothing can be considered except in terms of political relations and power dynamics. From toilet functions, to one’s choice of entertainment genres, to whom one takes as friends, to larger social and electoral questions, all things are seen through the lens of ideology now. It’s not even a sliding scale anymore. All of it is equally as political, and equally as contentious. Where and how you shit, is as political an act, as who you vote for.

The role of the private sphere of life has been drastically eroded and diminished over the last twenty-five years, by the exploitation of network technology in the form of social media — and the public scrutiny of private life doesn’t stop with Twitter or Facebook. Everywhere, network connected devices are collecting data about your activities, your choices, your relationships, your habits, and your preferences. Doorbells, televisions, stereo systems, building security systems, and of course, computers and now the ubiquitous smartphone, all have microphones, cameras, GPS trackers, ‘call home’ beacons, and various other means of generating and vomiting data about you, to massive commercial institutions that are more than willing to hand that information over to political institutions, or even to openly publicize it for no other reason than to increase the potential for revenue generation. All digital records are fair game for exploitation. Emails, purchase receipts, government documents, video recordings, audio recordings, private chats, even files stored on local hard disks — if they’re connected to the internet, they’re “public” in some sense enough to skirt legal limits. If your mother notes your birthday on her Facebook page, your birthdate is public record. If your girlfriend breaks up with you and rants about it on Twitter, your relationship status is public record. If you add your friends to your snapchat address book, your friends contact information is public record. What’s more, if it’s public, the automatic assumption is that it is fodder for not just commercial, but *political* action. Celebrity is now an abundant commodity, diluted across the entire population of internet-connected citizens, whether it wants that status or not. If you have a phone number, you are as much a celebrity as Megan Markle. The only difference, is that not everyone has heard of you yet.

Where does this leave the status of the sphere of the private? When the only barrier left between public and private, is mere ignorance of your presence in this new ubiquitous public sphere, can it really be said that there is a private sphere anymore?

### Deliniating the spheres

The realm of the public, is the realm of the political. The political realm is the realm of closed systems, binary choices, and global effects. It is the realm of finite possibility. It is characterized by a fixed amount of power which is fought over for access to a certain list of privileges not available to us in the private sphere of life: namely, the privilege of wielding the means of **force** and **fear**. Within this sphere, life is a continuous process of movement from submission to dominance, and back again. Hierarchies of aggression form around pyramidal peaks personified in the form of a leader (a president, or a prime minister, or a king, or a dictator). The better you are at wielding the tools of force and fear, the higher up the hierarchy you climb, and the larger your slice of the public pie.

The realm of life that was intended for the delicate subtlety of multivariate interpersonal connection and the complexity of individual choice, was the private sphere. It was meant to be the space of open possibility, and freedom of movement. A place where you could experiment, and make mistakes, and where cascading consequences (whether good or bad) would be mitigated by the extent of your personal network of friends and colleagues. Private life grows in scope and variety with our choices and our social connections, rather than shrinking and homogenizing, as we climb the power ladder in the public sphere. The private sphere is a realm meant to function as a bulwark against the political, and within which a wholly different set of privileges function as the operative motivators: the privileges of preference and love. Notions like the institutions of courtship and marriage, the legal concept of property, and the common sense understanding of freedom of conscience and association, signify both a desire for stability, and a healthy antagonism with the public sphere. These features of the private sphere make it so that dominance and control – if they work at all – can only have a limited effectiveness. Where individuals have the freedom of a myriad of choices available to them, hierarchies of aggression are going to dry up quickly, as people leave them for better pastures, and the aggressive find themselves isolated and unable to function. Private life requires the creation of value that can be combined and traded. A range of different values – from good critical thinking skills, to a good sense of humor, to technical prowess, to the traditional virtues of nobility – when cultivated, make individuals in the private sphere appealing, and they often inspire collaboration and creative activity. In the realm of the public, these values get cannibalized, and parasitized. Those who have managed to wrest access to the privilege of force and fear, often want to be seen as possessing the privilege of preference and love, because the latter is far more highly prized (in spite of the superficial appearance to the opposite).

When I was growing up in the 1970’s and 1980’s, the public/political sphere of life, even as late as then, still occupied a relatively minor place in day-to-day living. The “news” could be had twice a day, at 6PM and 10PM (and its content was largely confined to the most major events). Newspapers provided long-form commentary on the week’s most significant happenings. Elections ticked off in ritual succession, with ad campaigns being limited to short periods of time in the run up to election day. From time to time, people would gather in front of the state or federal capitol to bemoan a war or complain about some domestic issue. Even with the rise of the 24-hour cable TV news cycle, this remained largely the reality (at least until the events of 9/11). One could live one’s entire private life without even so much as a mention of a president, a governor, or even a mayor, and only come into contact with the public sphere for necessities like a driver’s licence or a marriage certificate. The public or private doings of private citizens anywhere else in the world were an extremely rare topic of conversation, and never a question of whether one ought to have a voice in any moral plebiscite about it.

This is no longer the case, today. The public sphere of life has intruded into and saturated almost everything we do. The ubiquitous presence of internet-connected devices, and the constant stream of data they feed to a hungry public, offer a constant diet of political debate, analysis, discussion, and moral judgment – all day, every day, leaving only a small space in the dead of night for a few hour’s nap (and even that is now threatened). One cannot go to a restaurant, have a spat with one’s spouse, grumble about work frustrations, attend a movie, or even just sit contemplating on one’s front porch, without someone, somewhere on the internet, knowing about it and providing public commentary on it.

What’s especially bizarre about this change, is that it has not been forced upon us. We have at least passively volunteered to expose ourselves in this way. We gladly hand over our geolocation, photos, videos, personal and legal details, relationship information, and loads of other personal details, precisely in the hope that others will see it, and respond to it. We have embraced the potential for celebrity with open arms. In the process, we have willingly accepted the destruction of the private, and along with it, we are welcoming our own demise.

Why am I saying all this? Am I just being hyperbolic? Is this just another case of “elderly luddite hates those kids and their new-fangled gadgets”? Perhaps. But I don’t think so. You see, even with the rise of 24×7 cable television, you could always still *turn it off*. But that’s not possible anymore. The ubiquity of internet-connected devices means you cannot escape being noticed, or being forced to notice others, anywhere you go. Whether, by your own cell phone, or a street camera, or an ATM, or another person with a cell phone or laptop, the internet *is never really off*, even if we wanted it to be. But we don’t, do we? The gormless geniuses at these giant tech firms have managed to hack human psychology to the point that almost nobody can withstand the craving to be consumed by this omniscient devouring beast. What does this mean for mankind? What are the implications? The consequences? The prognosis for the future?

### A bleak future?

While reading a recent article in Areo magazine, I stumbled across a quote from Hayek’s Constitution of Liberty, which expresses a very similar concern as I have been outlining so far:

> *…what distinguishes a free society from an unfree society is that in the former, each individual has a recognized private sphere, distinct from the public sphere, and the private individual cannot be ordered about but is expected to obey only those rules which are equally applicable to all…*

In addition to venerating the rule of law with this quote, the author of the article is using it as part of an argument defending religious freedom. But the more fundamental insight in this quote, in my view, is that freedom begins where they domain of the public ends. The more the domain of the public encroaches on the domain of the private and the personal, the less liberty and autonomy the individual will have. The fact that this encroachment is taking place with the tacit (and even active) assistance of so-called “private” corporate tech platforms, does not damage the fundamental point of this essay. Nor does it allay any of my original concerns. In the “digital” arena, life is a constant battle for position and “influence”. All actions are subject to moral plebiscite, and those at the top of the hierarchy determine not only the rules of the game, but who is allowed to participate in the game. Anyone found out-of-order is summarily sentenced in perpetuity (and typically in absentia), by a mob of self-appointed judges, jurists, and executioners. This new domain of public mob rule is beginning to have serious consequences in ever-expanding circles of bricks-and-mortar reality. Indeed, the internet’s Lord of the Flies tribal justice is costing people access to employment, banking services, business opportunities, and many other real life freedoms, all as a result of offending the ephemeral gods of the new public square. All these once entirely private matters have been commandeered into the public sphere of control, limiting choices, and diminishing the agency of free people to act as their private conscience dictates. Fear and force are now the ascendant principles. Love and preference are receding.

Even intimate partner relationships are not immune to this encroachment. As dating, childcare, relationship advice, and other once private aspects of life have moved online, thick boundaries between individual and group have radically blurred. With the help of the effectiveness of feminist attacks on family and gender roles, one can clearly see the relationship of private coupling grounded in social bonding, love, and personal preference, being transformed (distorted?) into a political union grounded in overt estimations of social cache, income parity, and pragmatism (in a sense, feminism is restoring the old feudal custom of political marriages of convenience, under the guise of progressive justice). When these new unions fail, the private ritual of dissolution is no longer the common habit. Now, there is a very public trial, in which at least one party must be shamed and demoted in the public space — sometimes even to the point of criminal punishment (see, for example, the bevy of stories coming from universities, in which men are constantly thrown onto a pyre for their failure to maintain favor with a woman). Gone is the notion of a mutual private feeling of love and respect, shared between equals in the eyes of God. In its place, we are erecting a framework of hierarchical public justice, in which coupled participants must continuously compete for top spot.

I am here reminded of the Kate Hepburn movie, “The Lion in Winter”, in which the entire family of Henry and Elenor of Aquitaine is engaged in a tortuous, self-destructive struggle to the death with each other, for access to Henry’s crown. The film portrays the drama as though it were a complex web of private familial entanglements, cursed only by the psychology of its participants. But, the tensions present are all about the political power struggle of Medieval England — an aging English King, his French competitor, his wife’s control of the Aquitaine, and his three jealous sons, all vying for the throne — and how that power struggle had infected and utterly diseased all the personal relationships. The political sphere had so interleaved itself into the private relationships, that they were virtually indistinguishable. Even Henry’s mistress mingles amongst the family openly, in an attempt to garner her own influence over the crown.

Second-wave feminists have a favorite slogan: *The personal is the political*. The argument behind this bromide is precisely that there is (or should be) no such thing as a private sphere of life – that every choice you make, by virtue of its source in political values and its implications for political life, is necessarily a political choice whether you want it to be or not. This is why many of them, at least in the 1970’s, made conscious decisions to live *as if* they were lesbians, even if they weren’t. The idea being that female empowerment means liberation from the patriarchy, and liberation from the patriarchy means rejecting the biological imperative to couple with a man for the sake of reproduction. This act presages the modern-day political struggle with the recently coined “transgender” movement. There’s is also an effort to rebel against the biological, in an effort to achieve some unspecified emancipation. In any case, the feminism of the 1970’s took the stereotype of Victorian England, with its feminine “private” domain and masculine “public” domain, to be the template of the patriarchy. Reading twentieth-century sensibilities backward into history, they imagined Victorians must have viewed the masculine “public” domain as the more “superior” or “important” of the two, and reacted against that — not by questioning their own interpretation of Victorian England through a Deridian lens of “false hierarchy”, but by committing themselves to the obliteration of the “less superior” private domain, and the total colonization of the “more superior” public domain, so that, in the end, there can be no space in society where a woman might be rendered “unimportant”. The advent of the internet has provided them a massive set of weapons with which to wage that war.

George Orwell seems to have sensed this assault, as well. In his well-worn novel *Nineteen Eighty-four* (celebrating it’s 70th anniversary this year), Winston Smith is locked in a doomed struggle to preserve some private space of his own, and some sense of his own private self, in the form of animal desire, aspiration, and an escape into the life of the mind. The novel opens with Smith attempting to hide from the all-seeing tele-screen in order to write a letter to the future, in an illegally acquired pen-and-paper journal. As the novel progresses, he becomes more bold, and tries to expand his sphere of private life to incorporate a relationship. Smith seems self-conscious of what he’s doing, too, as this passage describing a triste between Smith and Julia attests:

> In the old days, [Winston] thought, a man looked at a girl’s body and saw that it was desirable, and that was the end of the story. But you could not have pure love or pure lust nowadays. No emotion was pure, because everything was mixed up with fear and hatred. Their embrace had been a battle, the climax a victory. It was a blow struck against the Party. It was a political act…

This passage also clearly predicts the consequences of intermingling private and public, as I have outlined above. The open landscape of love and preference are gone, and in its wake, all that is left is the closed loop of fear and force. Orwell pessimistically crafts the story in such a way that Smith’s desire for a private life is his Achille’s Heel. His relationship with Julia turns out to be a trap, and even his attempt to recede into his own mind is rendered vain. In the end, for Orwell, this struggle between the public and the private can only end inevitably in the destruction of the private. He may have a point.

By saturating all of life with a public, political character, and eliminating any sense of private, apolitical, personal interaction, we’re effectively destroying the avenues for creative problem-solving, for the proliferation of choice, for the possibility of negotiation and trade, and for the mitigation of problems of hierarchy (ironically), and primarily, for the possibility of virtue. The public, political sphere is necessarily a realm of diminishing binaries, of rigid hierarchy, of threats of force, and “necessary evils”. Feminism, and other neo- and anti-Enlightenment movements have made a Frankenstein out of the most decrepit body parts of Hobbes, Rousseau, Marx and Nietzsche by commandeering the very “patriarchal” structures they decry, distorting them into a shape they cannot take, and using their distorted forms to attempt to grind our natural, private impulses out of us, in pursuit of a more perfect reality. They have resumed the task of Socrates and Augustine, of bringing about God’s kingdom on Earth, and from where I’m sitting, it looks to me like they are forging yet another hell we’ll all have to suffer through. Returning to Orwell, I think O’Brien summarizes the end-game quite chillingly:

> …The old civilizations claimed that they were founded on love and justice. Ours is founded upon hatred. In our world there will be no emotions except fear, rage, triumph, and self-abasement. Everything else we shall destroy — everything. Already we are breaking down the habits of thought which have survived from before the Revolution. We have cut the links between child and parent, and between man and man, and between man and woman. No one dares trust a wife or a child or a friend any longer. But in the future there will be no wives and no friends. Children will be taken from their mothers at birth, as one takes eggs from a hen. The sex instinct will be eradicated. Procreation will be an annual formality like the renewal of a ration card. We shall abolish the orgasm. Our neurologists are at work upon it now. There will be no loyalty, except loyalty toward the Party. There will be no love, except the love of Big Brother. There will be no laughter, except the laugh of triumph over a defeated enemy. There will be no art, no literature, no science. When we are omnipotent we shall have no more need of science. There will be no distinction between beauty and ugliness. There will be no curiosity, no employment of the process of life. All competing pleasures will be destroyed. But always — do not forget this, Winston — always there will be the intoxication of power, constantly increasing and constantly growing subtler. Always, at every moment, there will be the thrill of victory, the sensation of trampling on an enemy who is helpless…

### Conclusion: what do we do about it?

Is O’Brien right? Is this ultimately where we are headed? I imagine it must have seemed so, to careful observers like Orwell, in the 1940’s. And, as I’ve outlined so far, the remainder of the twentieth century seems to have validated him. I don’t lay the cause of this erosion entirely at the feet of technology. I think it has simply functioned as a tool for increasing the speed of a change already underway. The question is, can we turn it against that change? Can we use this tool for good, rather than evil? There are few signs today, that we can.

For us to fully recover from the choices of the twentieth century, we’re somehow going to have to recover the sphere of the private from our own yearning to publicize everything. That must happen now, in an environment in which every cultural product encourages us not to. Such a change is going to require an enormous amount of intellectual and social maturity, and personal discipline. What would that look like, in practice? Do we abandon the smartphone? Put ourselves on a quota system? Disconnect altogether? Transition to some new form of technology? All of these measures are directed at the proximal cause, not the final one. That, I think, is ironically a political problem. We need to rediscover ourselves as individuals in some way that integrates local connections, rather than global ones. We need to reaffirm the importance of the family, and of trust relationships, and make it worthwhile for the next generation to value the same. In the absense of this, the sphere of the public will continue to expand and consume everything, and with it, any likelihood of redemption.
